@@ -178,6 +178,7 @@ SensorFaceControllerPrivate::SensorFaceControllerPrivate()
             { QRegularExpression(QStringLiteral("nvidia/(.*)/processorClock$")), QStringLiteral("gpu/\\1/coreFrequency")},
             { QRegularExpression(QStringLiteral("nvidia/(.*)/(memory|sharedMemory)$")), QStringLiteral("gpu/\\1/usedVram")},
             { QRegularExpression(QStringLiteral("nvidia/(.*)/(encoderUsage|decoderUsage)$")), QStringLiteral("gpu/\\1/usage")},
+            { QRegularExpression(QStringLiteral("(uptime|system/uptime/uptime)$")), QStringLiteral("os/system/uptime")},
         };
     }
 }
@@ -389,15 +390,19 @@ SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *eng
 SensorFaceController::~SensorFaceController()
 {
     auto forceSave = d->faceProperties.readEntry(QStringLiteral("ForceSaveOnDestroy"), false);
-    if (!d->shouldSync && !forceSave) {
-        // If we should not sync automatically, clear all changes before we
-        // destroy the config objects, otherwise they will be written during
-        // destruction.
-        d->appearanceGroup.markAsClean();
-        d->colorsGroup.markAsClean();
-        if (d->faceConfigLoader && d->faceConfigLoader->isSaveNeeded()) {
-            d->faceConfigLoader->load();
+    if (!forceSave) {
+        if (!d->shouldSync) {
+            // If we should not sync automatically, clear all changes before we
+            // destroy the config objects, otherwise they will be written during
+            // destruction.
+            d->appearanceGroup.markAsClean();
+            d->colorsGroup.markAsClean();
+            if (d->faceConfigLoader && d->faceConfigLoader->isSaveNeeded()) {
+                d->faceConfigLoader->load();
+            }
         }
+    } else {
+        d->faceConfigLoader->save();
     }
 }
 
@@ -408,7 +413,7 @@ QString SensorFaceController::title() const
         return d->appearanceGroup.readEntry("title");
     } else {
         // if neither exist fall back to name
-        return d->appearanceGroup.readEntry("Title", name());
+        return d->appearanceGroup.readEntry("Title", i18n("System Monitor Sensor"));
     }
 }
 
@@ -558,6 +563,23 @@ void SensorFaceController::setLowPrioritySensorIds(const QJsonArray &lowPriority
     });
 }
 
+int SensorFaceController::updateRateLimit() const
+{
+    return d->appearanceGroup.readEntry<int>(QStringLiteral("updateRateLimit"), 0);
+}
+
+void SensorFaceController::setUpdateRateLimit(int limit)
+{
+    if (limit == updateRateLimit()) {
+        return;
+    }
+
+    d->appearanceGroup.writeEntry("updateRateLimit", limit);
+    d->syncTimer->start();
+
+    Q_EMIT updateRateLimitChanged();
+}
+
 // from face config, immutable by the user
 QString SensorFaceController::name() const
 {
@@ -782,6 +804,7 @@ void SensorFaceController::reloadConfig()
     Q_EMIT titleChanged();
     Q_EMIT sensorColorsChanged();
     Q_EMIT showTitleChanged();
+    Q_EMIT updateRateLimitChanged();
 }
 
 void SensorFaceController::loadPreset(const QString &preset)
