@@ -42,7 +42,7 @@ class KSysGuard::CGroupDataModelPrivate
 public:
     QVector<KSysGuard::Process*> processesFor(CGroup *app);
 
-    ExtendedProcesses *m_processes;
+    QSharedPointer<ExtendedProcesses> m_processes;
     QTimer *m_updateTimer;
     ProcessAttributeModel *m_attributeModel = nullptr;
     QHash<QString, KSysGuard::ProcessAttribute* > m_availableAttributes;
@@ -104,7 +104,7 @@ CGroupDataModel::CGroupDataModel(const QString &root, QObject *parent)
     , d(new CGroupDataModelPrivate)
 {
     d->m_updateTimer = new QTimer(this);
-    d->m_processes = new ExtendedProcesses(this);
+    d->m_processes = ExtendedProcesses::instance();
 
     QVector<ProcessAttribute *> attributes = d->m_processes->attributes();
     attributes.reserve(attributes.count() + 3);
@@ -125,6 +125,13 @@ CGroupDataModel::CGroupDataModel(const QString &root, QObject *parent)
     d->m_updateTimer->setInterval(2000);
     d->m_updateTimer->start();
 
+    // updateAllProcesses will delete processes that no longer exist, a method that
+    // can be called by any user of the shared Processes
+    // so clear out our cache of cgroup -> process whenever anything gets removed
+    connect(d->m_processes.data(), &Processes::beginRemoveProcess, this, [this]() {
+        d->m_processMap.clear();
+    });
+
     setRoot(root);
 }
 
@@ -209,12 +216,10 @@ void CGroupDataModel::setEnabledAttributes(const QStringList &enabledAttributes)
              emit dataChanged(index, index);
          });
 
-         attr->setEnabled(true);
      }
 
      for (auto unusedAttr : qAsConst(unusedAttributes)) {
          disconnect(unusedAttr, &KSysGuard::ProcessAttribute::dataChanged, this, nullptr);
-         unusedAttr->setEnabled(false);
      }
 
      endResetModel();
@@ -352,6 +357,7 @@ void CGroupDataModel::setEnabled(bool enabled)
 {
     if (enabled) {
         d->m_updateTimer->start();
+        QMetaObject::invokeMethod(this, [this] {update();}, Qt::QueuedConnection);
     } else {
         d->m_updateTimer->stop();
     }
@@ -394,14 +400,9 @@ void CGroupDataModel::update()
 
     d->m_oldGroups = d->m_cgroupMap;
 
-    // updateAllProcesses will delete processes that no longer exist, so clear
-    // out our cache of the processes before that happens so we have no dangling
-    // processes.
-    d->m_processMap.clear();
-
     // In an ideal world we would only the relevant process
     // but Ksysguard::Processes doesn't handle that very well
-    d->m_processes->updateAllProcesses();
+    d->m_processes->updateAllProcesses(d->m_updateTimer->interval());
 
     update(d->m_rootGroup.data());
 
@@ -433,6 +434,7 @@ void CGroupDataModel::update(CGroup *node)
         auto row = d->m_cGroups.indexOf(node);
         if (row >= 0) {
             d->m_cGroups[row]->setPids(pids);
+            d->m_processMap.remove(d->m_cGroups[row]);
             Q_EMIT dataChanged(index(row, 0, QModelIndex()), index(row, columnCount()-1, QModelIndex()));
         }
     });
